#!/usr/bin/env python3

from setuptools import setup

setup(
    name="robotpy-commands-v1",
    version="0.1",
    description="Placeholder",
    author="Dustin Spicuzza",
    author_email="robotpy@googlegroups.com",
    license="BSD-3-Clause",
    packages=["px.b"],
    include_package_data=True,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development",
    ],
)
